pub struct InstrumentedSendRequest<S> { /* private fields */ }Expand description
A reusable wrapper around hyper SendRequest that records client spans for
each request sent through the connection.
Implementations
Sourceimpl<B: Body + 'static> InstrumentedSendRequest<SendRequest<B>>
impl<B: Body + 'static> InstrumentedSendRequest<SendRequest<B>>
Sourcepub fn poll_ready(&mut self, cx: &mut TaskContext<'_>) -> Poll<Result<()>>
pub fn poll_ready(&mut self, cx: &mut TaskContext<'_>) -> Poll<Result<()>>
Polls until the underlying sender is ready to send a request.
Sourceimpl<B: Body + 'static> InstrumentedSendRequest<SendRequest<B>>
impl<B: Body + 'static> InstrumentedSendRequest<SendRequest<B>>
Sourcepub fn poll_ready(&mut self, cx: &mut TaskContext<'_>) -> Poll<Result<()>>
pub fn poll_ready(&mut self, cx: &mut TaskContext<'_>) -> Poll<Result<()>>
Polls until the underlying sender is ready to send a request.
Sourceimpl<S> InstrumentedSendRequest<S>
impl<S> InstrumentedSendRequest<S>
Sourcepub fn context(self, context: &Context) -> Self
pub fn context(self, context: &Context) -> Self
Sets the OpenTelemetry context for requests sent by this wrapper.
Sourcepub fn set_context(self, context: Option<&Context>) -> Self
pub fn set_context(self, context: Option<&Context>) -> Self
Sets the optional OpenTelemetry context for requests sent by this wrapper.
Sourcepub fn into_inner(self) -> S
pub fn into_inner(self) -> S
Returns the wrapped hyper sender.