SecretsManagerSpanBuilder

Enum SecretsManagerSpanBuilder 

pub enum SecretsManagerSpanBuilder {}
Builder for Secrets Manager-specific OpenTelemetry spans.

This enum serves as a namespace for Secrets Manager operation span builders. Each operation provides a specific method to create properly configured spans with Secrets Manager-specific attributes.

Implementations

Source

impl SecretsManagerSpanBuilder

pub fn get_secret_value<'a>( secret_id: impl Into<StringValue>, ) -> AwsSpanBuilder<'a>

Creates a span builder for the Secrets Manager get_secret_value operation.

Arguments
  • secret_id - The name or ARN of the secret
Source

impl SecretsManagerSpanBuilder

pub fn put_secret_value<'a>( secret_id: impl Into<StringValue>, ) -> AwsSpanBuilder<'a>

Creates a span builder for the Secrets Manager put_secret_value operation.

Arguments
  • secret_id - The name or ARN of the secret
Source

impl SecretsManagerSpanBuilder

pub fn create_secret<'a>( secret_id: impl Into<StringValue>, ) -> AwsSpanBuilder<'a>

Creates a span builder for the Secrets Manager create_secret operation.

Arguments
  • secret_id - The name or ARN of the secret
Source

impl SecretsManagerSpanBuilder

pub fn delete_secret<'a>( secret_id: impl Into<StringValue>, ) -> AwsSpanBuilder<'a>

Creates a span builder for the Secrets Manager delete_secret operation.

Arguments
  • secret_id - The name or ARN of the secret
Source

impl SecretsManagerSpanBuilder

pub fn describe_secret<'a>( secret_id: impl Into<StringValue>, ) -> AwsSpanBuilder<'a>

Creates a span builder for the Secrets Manager describe_secret operation.

Arguments
  • secret_id - The name or ARN of the secret
Source

impl SecretsManagerSpanBuilder

pub fn update_secret<'a>( secret_id: impl Into<StringValue>, ) -> AwsSpanBuilder<'a>

Creates a span builder for the Secrets Manager update_secret operation.

Arguments
  • secret_id - The name or ARN of the secret
Source

impl SecretsManagerSpanBuilder

pub fn restore_secret<'a>( secret_id: impl Into<StringValue>, ) -> AwsSpanBuilder<'a>

Creates a span builder for the Secrets Manager restore_secret operation.

Arguments
  • secret_id - The name or ARN of the secret
Source

impl SecretsManagerSpanBuilder

pub fn rotate_secret<'a>( secret_id: impl Into<StringValue>, ) -> AwsSpanBuilder<'a>

Creates a span builder for the Secrets Manager rotate_secret operation.

Arguments
  • secret_id - The name or ARN of the secret
Source

impl SecretsManagerSpanBuilder

pub fn cancel_rotate_secret<'a>( secret_id: impl Into<StringValue>, ) -> AwsSpanBuilder<'a>

Creates a span builder for the Secrets Manager cancel_rotate_secret operation.

Arguments
  • secret_id - The name or ARN of the secret
Source

impl SecretsManagerSpanBuilder

pub fn update_secret_version_stage<'a>( secret_id: impl Into<StringValue>, ) -> AwsSpanBuilder<'a>

Creates a span builder for the Secrets Manager update_secret_version_stage operation.

Arguments
  • secret_id - The name or ARN of the secret
Source

impl SecretsManagerSpanBuilder

pub fn list_secret_version_ids<'a>( secret_id: impl Into<StringValue>, ) -> AwsSpanBuilder<'a>

Creates a span builder for the Secrets Manager list_secret_version_ids operation.

Arguments
  • secret_id - The name or ARN of the secret
Source

impl SecretsManagerSpanBuilder

pub fn tag_resource<'a>(secret_id: impl Into<StringValue>) -> AwsSpanBuilder<'a>

Creates a span builder for the Secrets Manager tag_resource operation.

Arguments
  • secret_id - The name or ARN of the secret
Source

impl SecretsManagerSpanBuilder

pub fn untag_resource<'a>( secret_id: impl Into<StringValue>, ) -> AwsSpanBuilder<'a>

Creates a span builder for the Secrets Manager untag_resource operation.

Arguments
  • secret_id - The name or ARN of the secret
Source

impl SecretsManagerSpanBuilder

pub fn get_resource_policy<'a>( secret_id: impl Into<StringValue>, ) -> AwsSpanBuilder<'a>

Creates a span builder for the Secrets Manager get_resource_policy operation.

Arguments
  • secret_id - The name or ARN of the secret
Source

impl SecretsManagerSpanBuilder

pub fn put_resource_policy<'a>( secret_id: impl Into<StringValue>, ) -> AwsSpanBuilder<'a>

Creates a span builder for the Secrets Manager put_resource_policy operation.

Arguments
  • secret_id - The name or ARN of the secret
Source

impl SecretsManagerSpanBuilder

pub fn delete_resource_policy<'a>( secret_id: impl Into<StringValue>, ) -> AwsSpanBuilder<'a>

Creates a span builder for the Secrets Manager delete_resource_policy operation.

Arguments
  • secret_id - The name or ARN of the secret
Source

impl SecretsManagerSpanBuilder

pub fn validate_resource_policy<'a>( secret_id: impl Into<StringValue>, ) -> AwsSpanBuilder<'a>

Creates a span builder for the Secrets Manager validate_resource_policy operation.

Arguments
  • secret_id - The name or ARN of the secret
Source

impl SecretsManagerSpanBuilder

pub fn remove_regions_from_replication<'a>( secret_id: impl Into<StringValue>, ) -> AwsSpanBuilder<'a>

Creates a span builder for the Secrets Manager remove_regions_from_replication operation.

Arguments
  • secret_id - The name or ARN of the secret
Source

impl SecretsManagerSpanBuilder

pub fn replicate_secret_to_regions<'a>( secret_id: impl Into<StringValue>, ) -> AwsSpanBuilder<'a>

Creates a span builder for the Secrets Manager replicate_secret_to_regions operation.

Arguments
  • secret_id - The name or ARN of the secret
Source

impl SecretsManagerSpanBuilder

pub fn stop_replication_to_replica<'a>( secret_id: impl Into<StringValue>, ) -> AwsSpanBuilder<'a>

Creates a span builder for the Secrets Manager stop_replication_to_replica operation.

Arguments
  • secret_id - The name or ARN of the secret
Source

impl SecretsManagerSpanBuilder

pub fn list_secrets<'a>() -> AwsSpanBuilder<'a>

Creates a span builder for the Secrets Manager list_secrets operation.

Source

impl SecretsManagerSpanBuilder

pub fn batch_get_secret_value<'a>() -> AwsSpanBuilder<'a>

Creates a span builder for the Secrets Manager batch_get_secret_value operation.

Source

impl SecretsManagerSpanBuilder

pub fn get_random_password<'a>() -> AwsSpanBuilder<'a>

Creates a span builder for the Secrets Manager get_random_password operation.